<?php
/**
*
* @package phpBB3
* @version $Id: prime_birthdate.php,v 1.0.0 2007/09/19 18:10:00 primehalo Exp $
* @copyright (c) 2007 Ken F. Innes IV
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/


/**
* Age (in years) at which COPPA no longer applies.
*/
if (!defined('COPPA_AGE_CUTOFF'))
{
	define('COPPA_AGE_CUTOFF', 13);
}


/**
* Minimum age at which a user can register. This is only used if 
* the minimum age isn't set in the database.
*/
if (!defined('MINIMUM_AGE'))
{
	define('MINIMUM_AGE', 4);
}

/*
* Make sure this file has not already been included.
*/
if (!defined('INCLUDES_PRIME_BIRTHDATE'))
{
	define('INCLUDES_PRIME_BIRTHDATE', true);


	/**
	* Creates the form fields for selecting the Allow Birthdates options
	*/
	function make_allow_birthdays_select($key, $select_id = 2)
	{
		global $user, $config;

		$options_array = array(
			1 => 'YES',
			0 => 'NO',
			2 => 'PRIME_BIRTHDATE_REQUIRE',
			3 => 'PRIME_BIRTHDATE_LOCK',
		);

		$select = ''; 
		$user->add_lang('mods/prime_birthdate');
		foreach ($options_array as $idx => $title)
		{
			$selected = ($config[$key] == $idx) ? ' checked="checked"' : '';
			$select .= '<label><input type="radio"' . ($idx == 1 ? 'id="' . $key . '"' : '') . ' name="config[' . $key . ']" value="' . $idx . '"' . $selected . ' class="radio" /> ' . $user->lang[$title] . '</label>' . "\n";
		}
		return($select);
	}


	/**
	*/
	function user_show_age($show)
	{
		if (is_array($show) && isset($show['user_show_age']))
		{
			$show = $show['user_show_age'];
		}
		$show = (is_int($show) && ($show & 0x01));
		return($show);
	}


	/**
	*/
	function user_show_congrats($show)
	{
		if (is_array($show) && isset($show['user_show_age']))
		{
			$show = $show['user_show_age'];
		}
		$show = (is_int($show) && ($show & 0x02));
		return($show);
	}

	/**
	* Returns a person's current age.
	* @param:  string - $date_of_birth (in the form "day-month-year")
	* @return: integer - Current age of individual based on the date of birth given.
	*/
	function get_age($date_of_birth) //day-month-year
	{
		$bdate = explode("-", $date_of_birth);
		$age = date("Y") - $bdate[2];
		if (($bdate[1] > date("m")) || ($bdate[1] == date("m") && date("d") < $bdate[0]))
		{
			$age -= 1;
		}
		return $age;
	}
	
	/**
	* Determines whether or not birthdates are a requiredment.
	*/
	function birthdate_required()
	{
		global $config;
		return (isset($config['allow_birthdays']) && $config['allow_birthdays'] >= 2);
	}
	
	/**
	* Determines whether or not birthdates can be changed. 
	* If not passing an argument, it returns the general board setting.
	* If passing in a birthdate, if returns true only if the board
	* setting is true and the birthdate is already valid.
	*/
	function birthdate_locked($date_of_birth = false)
	{
		global $config;

		$locked = (isset($config['allow_birthdays']) && $config['allow_birthdays'] == 3);
		if ($locked && $date_of_birth)
		{
			$locked = (birthdate_error($date_of_birth) === false);
		}
		return ($locked);
	}
	
	
	/**
	* Validates a birth date.
	* @param:  string - $date_of_birth (in the form "day-month-year")
	* @return: boolean|string - Either false if validation succeeded or a string
	*          which will be used as the error message.
	*/
	function birthdate_error($date_of_birth) //day-month-year
	{
		global $config;
		$minimum_age = isset($config['minimum_age']) ? $config['minimum_age'] : MINIMUM_AGE;
		$bdate = explode("-", $date_of_birth);
		if ((!$bdate[0] || !$bdate[1] || !$bdate[2]))
		{
			return 'PRIME_BIRTHDATE_EMPTY';
		}
		if ($bdate[0] < 0 || $bdate[0] > 31 || $bdate[1] < 0 || $bdate[1] > 12 || ($bdate[2] < 1901 && $bdate[2] > 0) || $bdate[2] > gmdate('Y', time()))
		{
			return 'PRIME_BIRTHDATE_ERROR';
		}
		if (checkdate($bdate[1], $bdate[0], $bdate[2]) === false)
		{
			return 'PRIME_BIRTHDATE_ERROR';
		}
		if (get_age($date_of_birth) < $minimum_age)
		{
			return 'PRIME_BIRTHDATE_BABY';
		}
		return(false);
	}

	
	/**
	* Creates the date options for the form dropdown select boxes.
	* @param:  string - $date_of_birth (in the form "day-month-year")
	* @return: array of strings - Each array element contains the options
	*          for a select dropdown box
	*/
	function get_birthdate_options($date_of_birth)
	{
		global $user;
		$bdate = explode("-", $date_of_birth); //day-month-year
	
		$s_birthday_day_options = '<option value="0"' . ((!$bdate[0]) ? ' selected="selected"' : '') . '>' . $user->lang['DAY'] . '</option>';
		for ($i = 1; $i < 32; $i++)
		{
			$selected = ($i == $bdate[0]) ? ' selected="selected"' : '';
			$s_birthday_day_options .= "<option value=\"$i\"$selected>$i</option>";
		}
	
		$s_birthday_month_options = '<option value="0"' . ((!$bdate[1]) ? ' selected="selected"' : '') . '>' . $user->lang['MONTH'] . '</option>';
		$lang_dates = array(1 => $user->lang['datetime']['Jan'], $user->lang['datetime']['Feb'], $user->lang['datetime']['Mar'], $user->lang['datetime']['Apr'], $user->lang['datetime']['May_short'], $user->lang['datetime']['Jun'], $user->lang['datetime']['Jul'], $user->lang['datetime']['Aug'], $user->lang['datetime']['Sep'], $user->lang['datetime']['Oct'], $user->lang['datetime']['Nov'], $user->lang['datetime']['Dec']);
		for ($i = 1; $i < 13; $i++)
		{
			$selected = ($i == $bdate[1]) ? ' selected="selected"' : '';
			$s_birthday_month_options .= "<option value=\"$i\"$selected>{$lang_dates[$i]}</option>";
		}
	
		$now = getdate();
		$s_birthday_year_options = '<option value="0"' . ((!$bdate[2]) ? ' selected="selected"' : '') . '>' . $user->lang['YEAR'] . '</option>';
		for ($i = $now['year']; $i > $now['year'] - 100; $i--)
		{
			$selected = ($i == $bdate[2]) ? ' selected="selected"' : '';
			$s_birthday_year_options .= "<option value=\"$i\"$selected>$i</option>";
		}
		unset($now);
		return(array($s_birthday_day_options, $s_birthday_month_options, $s_birthday_year_options));
	}
}
?>
